"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLogger = exports.LogLevel = void 0;
const util_1 = require("util");
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["TRACE"] = 100] = "TRACE";
    LogLevel[LogLevel["DEBUG"] = 200] = "DEBUG";
    LogLevel[LogLevel["INFO"] = 300] = "INFO";
    LogLevel[LogLevel["WARNING"] = 400] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 500] = "ERROR";
    LogLevel[LogLevel["CRITICAL"] = 600] = "CRITICAL";
    LogLevel[LogLevel["AUDIT"] = 999] = "AUDIT";
    LogLevel[LogLevel["AUDIT_ALERT"] = 999] = "AUDIT_ALERT";
    LogLevel[LogLevel["SUPPRESS"] = 1000] = "SUPPRESS";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
/**
 * Returns a new logger instance given the options provided.
 * @param {LoggerOptions} options
 */
function getLogger(options) {
    const defaultSettings = {
        level: _resolveLogLevel(options?.level, process.env.LOG_LEVEL),
        prefix: '',
        timestamp: false,
    };
    const settings = Object.assign(defaultSettings, options || {});
    return {
        trace: (message, attachment) => {
            _log(LogLevel.TRACE, message, attachment);
        },
        debug: (message, attachment) => {
            _log(LogLevel.DEBUG, message, attachment);
        },
        info: (message, attachment) => {
            _log(LogLevel.INFO, message, attachment);
        },
        warning: (message, attachment) => {
            _log(LogLevel.WARNING, message, attachment);
        },
        error: (message, attachment) => {
            _log(LogLevel.ERROR, message, attachment);
        },
        critical: (message, attachment) => {
            _log(LogLevel.CRITICAL, message, attachment);
        },
        audit: (message, attachment) => {
            _log(LogLevel.AUDIT, message, attachment);
        },
        auditAlert: (message, attachment) => {
            _log(LogLevel.AUDIT_ALERT, message, attachment);
        },
        getSettings: () => {
            return settings;
        },
    };
    function _log(logLevel, message, attachment) {
        if (settings.level <= logLevel) {
            let formattedMessage;
            if (settings.timestamp) {
                formattedMessage = (0, util_1.format)('[%s] %s %s%s', LogLevel[logLevel], new Date().toISOString(), settings.prefix, message);
            }
            else {
                formattedMessage = (0, util_1.format)('[%s] %s%s', LogLevel[logLevel], settings.prefix, message);
            }
            /* tslint:disable: no-console */
            if (attachment) {
                console.log(formattedMessage, (0, util_1.inspect)(attachment, false, null));
            }
            else {
                console.log(formattedMessage);
            }
            /* tslint:enable: no-console */
        }
    }
}
exports.getLogger = getLogger;
/**
 * Resolves the log level for the logger instance.
 * Log level is resolved in the following order:
 * 1. Provided logLevel assuming that it is set and valid
 * 2. From process.env.LOG_LEVEL, assuming that it is set and valid
 * 3. Default LogLevel.INFO
 * @param level Optional specific log level
 * @param processLogLevel
 */
function _resolveLogLevel(level, processLogLevel) {
    if (level && LogLevel[level]) {
        return level;
    }
    else if (processLogLevel !== undefined && LogLevel[processLogLevel]) {
        return LogLevel[processLogLevel];
    }
    return LogLevel.INFO;
}
